<?php

namespace Drupal\pagedesigner_duplication\Service;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityFieldManager;
use Drupal\Core\Language\LanguageManager;
use Drupal\Core\Routing\CurrentRouteMatch;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\pagedesigner\PagedesignerService;
use Drupal\pagedesigner\Service\ElementHandler;
use Drupal\pagedesigner\Service\StateChanger;

/**
 * Service for duplicating pagedesigner content.
 */
class DuplicationService extends PagedesignerService {

  /**
   * Create a new instance.
   *
   *   The element handler.
   *   The language manager.
   *   The current route.
   *   The current user.
   *   The entity field manager.
   */
  public function __construct(protected StateChanger $statechanger, ElementHandler $element_handler, LanguageManager $language_manager, CurrentRouteMatch $current_route, AccountProxyInterface $current_user, EntityFieldManager $entity_field_manager) {
    parent::__construct($element_handler, $language_manager, $current_route, $current_user, $entity_field_manager);
  }

  /**
   * Clone the element tree.
   *
   * Clone the elements from on entity to another entity.
   * Only matching pagedesigner fields are taken into account.
   *
   * @param \Drupal\Core\Entity\ContentEntityBase $source
   *   The source entity.
   * @param \Drupal\Core\Entity\ContentEntityBase $target
   *   The target entity.
   */
  public function duplicate(ContentEntityBase $source, ContentEntityBase $target) {
    $sourceFields = $this->getPagedesignerFields($source);
    $targetFields = $this->getPagedesignerFields($target);
    foreach ($sourceFields as $field) {
      if (!empty($targetFields[$field->getName()])) {
        $sourceContainer = $this->getContainer($source, $field->getName());
        $targetContainer = $this->getContainer($target, $field->getName());

        // Make sure that target entity is set.
        $targetContainer->entity->entity = $target;

        foreach ($sourceContainer->children as $item) {
          $clone = $this->statechanger->copy($item->entity, $targetContainer)->getOutput();
          $clone->parent->entity = $targetContainer;
          $clone->langcode->value = $target->langcode->value;
          $clone->save();
          $targetContainer->children->appendItem($clone);
        }
        $targetContainer->save();
      }
    }
  }

}
